*open the household listing data file.
get file = 'c:/BiH/MICS3/hl.sav'.

* create a variable that will reflect mother's line number.
compute mline = hl1

* create what will be mother's education level.
recode ED3A (1 = 2) (2 = 3)(3,4 = 4) (6 = 5) (8,9 = 9) (else = 1)into melevel.
variable label melevel "Mother's education level".
value label melevel
  1 "None"
  2 "Primary"
  3 "Secondary"
  4 "Higher and University"
  5 "Non-standard curriculum"
  9 "Missing/DK".


* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* save a mother's education file.
save outfile = 'c:/BiH/MICS3/tmpme.sav'
  /keep HH1 HH2 mline melevel.

* create a variable that will reflect father's line number.
compute fline = hl1

* create what will be father's education level.
recode ED3A (1 = 2) (2 = 3)(3,4 = 4) (6 = 5) (8,9 = 9) (else = 1)into felevel.
variable label felevel "Father's education level".
value label felevel
  1 "None"
  2 "Primary"
  3 "Secondary"
  4 "Higher and University"
  5 "Non-standard curriculum"
  9 "Missing/DK".


* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* save a father's education file.
save outfile = 'c:/BiH/MICS3/tmpfe.sav'
  /keep HH1 HH2 fline felevel.

* keep heads of household only.
select if (hl3 = 1).

* create head of household's education level.
recode ED3A (1 = 2) (2 = 3)(3,4 = 4) (6 = 5) (8,9 = 9) (else = 1)into helevel.
variable label helevel "Head's education level".
value label helevel
  1 "None"
  2 "Primary"
  3 "Secondary"
  4 "Higher and University"
  5 "Non-standard curriculum"
  9 "Missing/DK".


* sort the cases by cluster number, household number and head's line number.
sort cases by HH1 HH2 HL1.

* save a household head's education file.
save outfile = 'c:/BiH/MICS3/tmphhe.sav'
  /keep HH1 HH2 HL1 helevel.

* open the household listing data file.
get file = 'c:/BiH/MICS3/hl.sav'.

* compute mother's line number for household members aged 14 or younger.
compute mline = 0.
if (HL7 <> 0) mline = HL7.
if (HL8 <> 0) mline = HL8.
variable label mline "Mother's line number".
Execute.

* compute mother's line number for household members aged 15, 16 and 17.
if (mline=0 and HL10>0) mline=HL10.

* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* merge the mother's education file onto the household listing file.
match files
  /file = *
  /table = 'c:/BiH/MICS3/tmpme.sav'
  /by HH1 HH2 mline.

* compute father's line number for household members aged 17 or younger.
compute fline = HL12.
variable label fline "Father's line number".

* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* merge the father's education file onto the household listing file.
match files
  /file = *
  /table = 'c:/BiH/MICS3/tmpfe.sav'
  /by HH1 HH2 fline.

* recode father's education level to deal with fathers who live elsewhere.
if (HL12 = 0) felevel = 6.
value label felevel
  1 "None"
  2 "Primary"
  3 "Secondary"
  4 "Higher and University"
  5 "Non-standard curriculum"
  6 "Father not at home" 
  9 "Missing/DK".


* sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* merge the household head file onto the household listing file.
match files
  /file = *
  /table = 'c:/BiH/MICS3/tmphhe.sav'
  /by HH1 HH2 .

* sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1 .

* save the household listing data file.
save outfile = 'c:/BiH/MICS3/hl.sav'.

* erase the working files.
erase file = 'c:/BiH/MICS3/tmpme.sav'.
erase file = 'c:/BiH/MICS3/tmpfe.sav'.
erase file = 'c:/BiH/MICS3/tmphhe.sav'.
