* open the women file.
get file ="c:/mics/spss/wm.sav".

* calculate the CMC date of interview.
compute cmcdoiw = (WM6Y - 1900)*12 + WM6M.
variable label cmcdoiw "Date of interview women (CMC)".

* set random number seed.
set seed = 1003.

* calculate the CMC date of birth and age.
do if (WM8Y < 9996 and WM8M < 96).
+ compute wdob = (WM8Y - 1900)*12 + WM8M.
else if (WM8Y < 9996).
+ compute aldob = cmcdoiw - WM9*12 - 11.
+ compute audob = cmcdoiw - WM9*12 - 0.
+ compute ldob = (WM8Y - 1900)*12 + 1.
+ compute udob = (WM8Y - 1900)*12 + 12.
+ if (ldob >= aldob & ldob <= audob) wdob = trunc(rv.uniform(ldob,audob)).
+ if (aldob >= ldob & aldob <= udob) wdob = trunc(rv.uniform(aldob,udob)).
+ if (ldob > audob | aldob > udob) wdob = trunc(rv.uniform(aldob,audob)).
else.
+ compute wdob = 9999.
end if.
if (cmcdoiw - wdob = 600) wdob = wdob + 1.
variable label wdob "Date of birth (CMC)".
missing values wdob (9999).

* calculate age in five year groups.
recode WM9 (15 thru 19 =1) (20 thru 24 = 2) (25 thru 29 =3) (30 thru 34 =4) 
	(35 thru 39 =5) (40 thru 44=6) (45 thru 49 =7) into wage.
variable label wage "Age".
value label wage
  1 "15-19"
  2 "20-24"
  3 "25-29"
  4 "30-34"
  5 "35-39"
  6 "40-44"
  7 "45-49".

* calculate age at first marriage.
do if (MA6Y < 9996 and MA6M < 96).
+ compute wdom = (MA6Y - 1900)*12 + MA6M.
+ compute agem = trunc ((wdom-wdob)/12) .
else if (MA8 < 96).
+ compute agem = MA8.
end if.
variable label agem "Age at first marriage/union".

* calculate age at first birth.
*	do if (CM2AY < 9996 and CM2AM < 96).
*	+ compute wdofb = (CM2AY - 1900)*12 + CM2AM.
*	+ compute agefb = trunc((cmcdoiw - wdofb)/12) .
*	else if (CM2B < 96).
*	+ compute agefb = CM2B.
*	
*	variable label agefb "Age at first birth".

* calculate age at last birth IF last birth in last two years.
do if (CM11Y < 9996 and CM11M < 96 and CM12 = "Y").
+ compute wdolb = (CM11Y - 1900)*12 + CM11M.
+ if (cmcdoiw - wdolb = 24) wdolb = wdolb + 1 .
else if (CM11Y < 9996 and CM12 = "Y").
+ compute udolb = (CM11Y - 1900)*12 + 12.
+ compute ldolb = (CM11Y - 1900)*12 + 1.
+ if (cmcdoiw - ldob >= 24) ldolb = cmcdoiw - 23.
+ compute wdolb = trunc(rv.uniform(ldolb,udolb)).
end if.
compute agelb = cmcdoiw - wdolb.
variable label agelb "Age in months of last birth".
variable label wdolb "Date of last birth (CMC)".

*create a recoded age variable for last birth.
recode agelb (0 thru 5 = 1) (6 thru 11 = 2) (12 thru 23 = 3) into agelbr.
variable label agelbr "Age in months of last birth".
value label agelbr
  1 "< 6 months"
  2 "6-11 months"
  3 "12-23 months".

* calculate marital status.
if (MA1 = 1 or MA1  = 2) mstatus = 1.
if (MA3 = 1 or MA3  = 2) mstatus = 2.
if (MA3 = 3) mstatus = 3.
variable label mstatus "Marital/Union status".
value label mstatus
  1 "Currently married /In union"
  2 "Formerly married/In union"
  3 "Never married/In union".

* calculate education level.
recode WM11 (1 = 2) (2 = 3)(3,4 = 4) (6 = 5) (8,9 = 9) (else = 1) into melevel.
variable label melevel "Woman's education level".
value label melevel
  1 "None"
  2 "Primary"
  3 "Secondary"
  4 "Higher and University"
  5 "Non-standard curriculum"
  9 "Missing/DK".

* calculate total children ever born.
*	compute ceb = 0.
*	if (CM1 = 1) ceb = CM9.
*	variable label ceb "Children ever born".

* calculate number of dead children.
*	compute deadkids = 0.
*	if (CM7 = 1) deadkids = CM8A + CM8B.
*	variable label deadkids "Dead children".

* ever heard of aids.
recode HA1 (1 = 100) (else = 0) into aids.
variable label aids "Heard of AIDS".

* reset variables for incomplete interviews.
do if (WM7 ~= 1).
+ recode wdob (lo thru hi=sysmis).
+ recode wage (lo thru hi=sysmis).
+ recode wdom (lo thru hi=sysmis).
+ recode agem (lo thru hi=sysmis).
+ recode mstatus (lo thru hi=sysmis).
+ recode melevel (lo thru hi=sysmis).
end if.

*save the women's file.
save outfile ="c:/mics/spss/wm.sav".

